jQuery MultiSelect Widget Demo

## Single Select

Setting the `multiple` parameter to false will force the widget to use radio buttons instead of checkboxes. I advise using the `header` parameter along with `multiple` in order to hide/change the "check all"/"uncheck all" links.

    $("select").multiselect({
       multiple: false,
       header: "Select an option",
       noneSelectedText: "Select an Option",
       selectedList: 1
    });